mod loadable;
mod output;
mod relocatable;
mod section;
mod symbol;

use std::path::Path;

pub use loadable::*;
pub use output::*;
pub use relocatable::*;
pub use section::*;
pub use symbol::*;

use crate::error::Error;

pub fn expand_path(path: &Path) -> Result<&str, Error> {
    use std::io::Error as IOError;
    use std::io::ErrorKind;

    path.to_str().ok_or_else(|| {
        let ioe = IOError::new(ErrorKind::Other, "Path expansion fail");
        let boxed = Box::new(ioe);
        Error::IOError(boxed)
    })
}

pub fn page_padding(offset: usize) -> usize {
    let page_size = page_size::get();

    let padding = page_size - (offset % page_size);

    padding
}

pub fn next_page(offset: usize) -> usize {
    let page_size = page_size::get();

    let page_count = (offset / page_size) + 1;
    
    page_count * page_size
}

